[−][src]Crate minitt
Modules
| normal | Normal form: when we read back, we get a normal form expression. |
| read_back | Read back: read back functions, converting terms to normal forms |
| reduce | Reduction: eval and eval's friends. |
| syntax | Syntax: term, expression, context.
Methods are inside the |
| type_check | Type checking: the four type checking functions. |